@@ -6,17 +6,11 @@ from .__config__ import (
     QproDefaultStatus,
     user_root,
     user_lang,
+    dir_char,
     os,
     sys,
 )
 
-if sys.platform.startswith("win"):
-    is_win = True
-    dir_char = "\\"
-else:
-    is_win = False
-    dir_char = "/"
-
 user_pip = _qpro_config.select("default_pip")
 using_gitee = _qpro_config.select("using_gitee")
 QproErrorString = f'[bold red][{_lang["error"]}][/]'
@@ -178,8 +172,8 @@ def requirePackage(
     :param module: 待引入的模块名，可缺省
     :param real_name: 用于 pip3 install 的名字
     :param not_exit: 安装后不退出
-    :param not_ask: 不询问是否安装
-    :param set_pip: 指定pip
+    :param not_ask: 不询问
+    :param set_pip: pip3的路径
     :return: 库或模块的地址
     """
     try:
@@ -187,30 +181,47 @@ def requirePackage(
     except (ModuleNotFoundError, ImportError):
         if not_ask:
             return None
-        confirm = _ask(
+        if _ask(
             {
                 "type": "confirm",
-                "name": "install",
-                "message": _lang["requirePackageDesc1"].format(
-                    pname + (" -> " + module if module else "")
-                ),
+                "message": f"""Qpro require {pname + (' -> ' + module if module else '')}, confirm to install?"""
+                if user_lang != "zh"
+                else f"""Qpro 依赖 {pname + (' -> ' + module if module else '')}，确认安装吗？""",
                 "default": True,
             }
-        )
-        if confirm:
-            os.system(f"{set_pip} install {pname if not real_name else real_name} -U")
+        ):
+            with QproDefaultStatus(
+                f"Installing {pname if not real_name else real_name}"
+                if user_lang != "zh"
+                else f"正在安装 {pname if not real_name else real_name}"
+            ):
+                st, _ = external_exec(
+                    f"{set_pip} install {pname if not real_name else real_name} -U",
+                    True,
+                )
+            if st:
+                QproDefaultConsole.print(
+                    QproErrorString,
+                    f"Install {pname + (' -> ' + module if module else '')} failed, please install it manually: "
+                    if user_lang != "zh"
+                    else f"安装 {pname + (' -> ' + module if module else '')} 失败，请手动安装: ",
+                    f"'{set_pip} install {pname if not real_name else real_name} -U'",
+                )
+                exit(-1)
             if not_exit:
                 exec(f"from {pname} import {module}" if module else f"import {pname}")
             else:
                 QproDefaultConsole.print(
                     QproInfoString,
-                    _lang["requirePackageDesc2"].format(" ".join(sys.argv)),
+                    "Install complete! Run again:"
+                    if user_lang != "zh"
+                    else f"安装完成！再次运行:",
+                    " ".join(sys.argv),
                 )
                 exit(0)
         else:
             exit(-1)
-    finally:
-        return eval(f"{module if module else pname}")
+    return eval(f"{module if module else pname}")
 
 
 class SshProtocol:
